import { useEffect, useState } from 'react'
import mq from 'js-mq'

const useScreenType = () => {
  const [isMobile, setIsMobile] = useState(null)

  useEffect(() => {
    if (typeof window !== 'undefined' && typeof document !== 'undefined') {
      try {
        mq.register([
          { name: 'mobile', query: '(max-width: 767px)' },
          { name: 'desktop', query: '(min-width: 768px)' }
        ])
        mq.on('mobile', (e) => {
          setIsMobile(true)
        })
        mq.on('desktop', (e) => {
          setIsMobile(false)
        })
        const arrayEstadoMq = mq.getState()
        if (arrayEstadoMq.length && (arrayEstadoMq[0] === 'not-mobile' || arrayEstadoMq[0] === 'desktop')) {
          setIsMobile(false)
        } else {
          setIsMobile(true)
        }
      } catch (e) {
        console.error(`Error al registrar mq breackpoints - ${e.message}`)
      }
    }
  }, [])

  return isMobile
}

export default useScreenType
